MoEngageNotificationHandler class

Handles notification callbacks and setup for MoEngage integration.

Constructors

MoEngageNotificationHandler()
Factory constructor to get the singleton instance.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isInitialized bool
Returns whether the notification handler has been initialized.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

initialize(MoEngageFlutter moengagePlugin) Future<void>
Initializes the MoEngage notification handler.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited